﻿local Engine, Api, Locale, Settings = unpack(Immersive)

local Configuration = Engine:GetModule("Configuration")

-- Register the module's configuration options panel.
function Configuration:OnRegisterOptions()
	local panel = self.Component
	
	-- The name of the AddOn or group of configuration options. This is
	-- the text that will display in the AddOn options list.
	panel.name = Locale.CONFIG_MODULE_IMMERSIVE_NAME

	-- Name of the parent of the AddOn or group of configuration
	-- options. This identifies "panel" as the child of another category.
	-- If the parent category doesn't exist, "panel" will be displayed as
	-- a regular category.
	panel.parent = nil

	panel.okay = Configuration.OnOkay
	panel.cancel = Configuration.OnCancel
	panel.default = Configuration.OnDefault
	panel.refresh = Configuration.OnRefresh

	-- Description
	local title = panel:CreateFontString("Title", "ARTWORK", "GameFontNormalLarge")
	title:SetJustifyH("LEFT")
	title:SetJustifyV("TOP")
	title:SetPoint("TOPLEFT", panel, "TOPLEFT", 16, -16)
	title:SetText(Locale.CONFIG_MODULE_IMMERSIVE_TITLE)

	local subText = panel:CreateFontString("Title", "ARTWORK", "GameFontHighlightSmall")
	subText:SetJustifyH("LEFT")
	subText:SetJustifyV("TOP")
	subText:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -8)
	subText:SetPoint("RIGHT", panel, "RIGHT", -32, 0)
	subText:SetText(Locale.CONFIG_MODULE_IMMERSIVE_SUBTEXT)

	-- Controls: Debug
	local debugMode = CreateFrame("CheckButton", string.format("%s%sDebugCheckButton", Engine.AddOnName, self.Name), panel, "InterfaceOptionsCheckButtonTemplate")
	debugMode:SetPoint("TOPLEFT", subText, "BOTTOMLEFT", -2, -8)
	debugMode:SetChecked(Settings:Get("DebugMode"))
	debugMode:SetScript("OnClick", function(self)
		Settings:Set("DebugMode", self:GetChecked())
	end)
	debugMode:SetScript("OnEnter", function(self)
		if self.Tooltip then
			GameTooltip:SetOwner(self, "ANCHOR_RIGHT");
			GameTooltip:SetText(self.Tooltip, nil, nil, nil, nil, true);
		end
	end)
	debugMode.Text:SetText(Locale.CONFIG_MODULE_IMMERSIVE_DEBUG_TEXT)
	debugMode.Tooltip = Locale.CONFIG_MODULE_IMMERSIVE_DEBUG_TOOLTIP

	-- Controls: Version
	local version = panel:CreateFontString("Version", "ARTWORK", "GameFontHighlight")
	version:SetJustifyH("LEFT")
	version:SetWidth(550)
	version:SetPoint("TOPLEFT", debugMode, "BOTTOMLEFT", 9, -15)
	version:SetText(string.format(Locale.CONFIG_MODULE_IMMERSIVE_VERSION_TEXT, Engine.Version))

	InterfaceOptions_AddCategory(panel)
end

-- This method will run when the player clicks "okay" in the Interface
-- Options.
function Configuration:OnOkay()
end

-- This method will run when the player clicks "cancel" in the Interface
-- Options. Use this to revert their changes.
function Configuration:OnCancel()
end

-- This method will run when the player clicks "defaults". Use this to
-- revert their changes to your defaults.
function Configuration:OnDefault()
end

-- This method will run when the Interface Options frame calls its OnShow
-- function and after defaults have been applied via the panel.default
-- method described above. Use this to refresh your panel's UI in case
-- settings were changed without player interaction.
function Configuration:OnRefresh()
end