﻿local Engine, Api, Locale, Settings = unpack(Immersive)

-- Constants
local CHATFRAME_NAME = "ChatFrame%d%s"

local Default = Engine:GetModule("Default")
local IsMessageReceived = false

-- Registers the element in classic mode.
function Default:RegisterChatFrameClassicMode()
	local settings = Settings:Get(self.Name).Elements["ChatFrame"]
	local chat = Api:RegisterElement("ChatFrame", settings)

	-- Add frames
	for i = 1, NUM_CHAT_WINDOWS do
		for _, type in pairs({ "", "Tab"}) do
			chat:AddFrame(_G[string.format(CHATFRAME_NAME, i, type)])
		end
	end
	chat:AddFrame(FriendsMicroButton)
	chat:AddFrame(ChatFrameMenuButton)
	
	-- Add conditions
	chat:AddConditionRange(settings.Conditions)
	chat:AddCondition(function() return ChatFrame1EditBox:IsShown() end)
	chat:AddCondition(function() return IsMessageReceived end)

	chat.OnFadeIn = function(self, frame, alpha)
		if alpha > 0 and frame.wasShown then
			frame.Show = frame.wasShown
			frame.wasShown = nil
			frame:Show()
		end
		if alpha == 1 then
			IsOpenRequested = false
		end
	end
	chat.OnFadeOut = function(self, frame, alpha)
		if alpha == 0 and frame:IsShown() then
			frame.wasShown = frame.Show
			frame.Show = function() end
			frame:Hide()
		end
	end

	-- Add hotspots
	self:RegisterChatFrameHotspots(chat)

	-- Add chat filters
	ChatFrame_AddMessageEventFilter("CHAT_MSG_BN_WHISPER", Default.OnClassicMessage)
	ChatFrame_AddMessageEventFilter("CHAT_MSG_WHISPER", Default.OnClassicMessage)
	ChatFrame_AddMessageEventFilter("CHAT_MSG_GUILD", Default.OnClassicMessage)
	ChatFrame_AddMessageEventFilter("CHAT_MSG_PARTY", Default.OnClassicMessage)
	ChatFrame_AddMessageEventFilter("CHAT_MSG_PARTY_LEADER", Default.OnClassicMessage)
	ChatFrame_AddMessageEventFilter("CHAT_MSG_RAID", Default.OnClassicMessage)
	ChatFrame_AddMessageEventFilter("CHAT_MSG_RAID_LEADER", Default.OnClassicMessage)
	ChatFrame_AddMessageEventFilter("CHAT_MSG_RAID_WARNING", Default.OnClassicMessage)
	ChatFrame_AddMessageEventFilter("CHAT_MSG_INSTANCE_CHAT", Default.OnClassicMessage)
	ChatFrame_AddMessageEventFilter("CHAT_MSG_INSTANCE_CHAT_LEADER", Default.OnClassicMessage)
end

-- Unregisters the element.
function Default:UnregisterChatFrameClassicMode()
	-- Remove chat filters
	ChatFrame_RemoveMessageEventFilter("CHAT_MSG_INSTANCE_CHAT_LEADER", Default.OnClassicMessage)
	ChatFrame_RemoveMessageEventFilter("CHAT_MSG_INSTANCE_CHAT", Default.OnClassicMessage)
	ChatFrame_RemoveMessageEventFilter("CHAT_MSG_RAID_WARNING", Default.OnClassicMessage)
	ChatFrame_RemoveMessageEventFilter("CHAT_MSG_RAID_LEADER", Default.OnClassicMessage)
	ChatFrame_RemoveMessageEventFilter("CHAT_MSG_RAID", Default.OnClassicMessage)
	ChatFrame_RemoveMessageEventFilter("CHAT_MSG_PARTY_LEADER", Default.OnClassicMessage)
	ChatFrame_RemoveMessageEventFilter("CHAT_MSG_PARTY", Default.OnClassicMessage)
	ChatFrame_RemoveMessageEventFilter("CHAT_MSG_GUILD", Default.OnClassicMessage)
	ChatFrame_RemoveMessageEventFilter("CHAT_MSG_WHISPER", Default.OnClassicMessage)
	ChatFrame_RemoveMessageEventFilter("CHAT_MSG_BN_WHISPER", Default.OnClassicMessage)
end

function Default:OnClassicMessage(event, message)
	IsMessageReceived = true
	return false -- Must return false so the chat message is not filtered
end